==> py_everything-2.0.0.tar.gz: py_everything-2.0.0/py_everything/units.py <==
# Mass
class mg:
    def __init__(self):
        self.name = 'MilliGram'
        self.unit = 'mg'
    
    def __repr__(self) -> str:
        return f'mg(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class cg:
    def __init__(self):
        self.name = 'CentiGram'
        self.unit = 'cg'
    
    def __repr__(self) -> str:
        return f'cg(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class dg:
    def __init__(self):
        self.name = 'DeciGram'
        self.unit = 'dg'
    
    def __repr__(self) -> str:
        return f'dg(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class g:
    def __init__(self):
        self.name = 'Gram'
        self.unit = 'g'
    
    def __repr__(self) -> str:
        return f'g(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class dag:
    def __init__(self):
        self.name = 'DekaGram'
        self.unit = 'dag'
    
    def __repr__(self) -> str:
        return f'dag(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class hg:
    def __init__(self):
        self.name = 'HectoGram'
        self.unit = 'hg'
    
    def __repr__(self) -> str:
        return f'hg(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class kg:
    def __init__(self):
        self.name = 'KiloGram'
        self.unit = 'kg'
    
    def __repr__(self) -> str:
        return f'kg(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

# Volume
class ml:
    def __init__(self):
        self.name = 'MilliLiter'
        self.unit = 'ml'
    
    def __repr__(self) -> str:
        return f'ml(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class cl:
    def __init__(self):
        self.name = 'CentiLiter'
        self.unit = 'cl'
    
    def __repr__(self) -> str:
        return f'cl(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class dl:
    def __init__(self):
        self.name = 'DeciLiter'
        self.unit = 'dl'
    
    def __repr__(self) -> str:
        return f'dl(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class l:
    def __init__(self):
        self.name = 'Liter'
        self.unit = 'l'
    
    def __repr__(self) -> str:
        return f'l(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class dal:
    def __init__(self):
        self.name = 'DekaLiter'
        self.unit = 'da'
    
    def __repr__(self) -> str:
        return f'da(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class hl:
    def __init__(self):
        self.name = 'HectoLiter'
        self.unit = 'hl'
    
    def __repr__(self) -> str:
        return f'hl(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class kl:
    def __init__(self):
        self.name = 'KiloLiter'
        self.unit = 'kl'
    
    def __repr__(self) -> str:
        return f'kl(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

# Length
class mm:
    def __init__(self):
        self.name = 'MilliMeter'
        self.unit = 'mm'
    
    def __repr__(self) -> str:
        return f'mm(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class cm:
    def __init__(self):
        self.name = 'CentiMeter'
        self.unit = 'cm'
    
    def __repr__(self) -> str:
        return f'cm(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class dm:
    def __init__(self):
        self.name = 'DeciMeter'
        self.unit = 'dm'
    
    def __repr__(self) -> str:
        return f'dm(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class m:
    def __init__(self):
        self.name = 'Meter'
        self.unit = 'm'
    
    def __repr__(self) -> str:
        return f'm(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class dam:
    def __init__(self):
        self.name = 'DekaMeter'
        self.unit = 'dam'
    
    def __repr__(self) -> str:
        return f'dam(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class hm:
    def __init__(self):
        self.name = 'HectoMeter'
        self.unit = 'hm'
    
    def __repr__(self) -> str:
        return f'hm(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class km:
    def __init__(self):
        self.name = 'KiloMeter'
        self.unit = 'km'
    
    def __repr__(self) -> str:
        return f'km(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}'

==> py_everything-2.1.0.tar.gz: py_everything-2.1.0/py_everything/units.py <==
# Mass
class mg:
    def __init__(self):
        self.name: str = 'MilliGram'
        self.unit: str = 'mg'
    
    def __repr__(self) -> str:
        return f'mg(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class cg:
    def __init__(self):
        self.name: str = 'CentiGram'
        self.unit: str = 'cg'
    
    def __repr__(self) -> str:
        return f'cg(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class dg:
    def __init__(self):
        self.name: str = 'DeciGram'
        self.unit: str = 'dg'
    
    def __repr__(self) -> str:
        return f'dg(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class g:
    def __init__(self):
        self.name: str = 'Gram'
        self.unit: str = 'g'
    
    def __repr__(self) -> str:
        return f'g(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class dag:
    def __init__(self):
        self.name: str = 'DekaGram'
        self.unit: str = 'dag'
    
    def __repr__(self) -> str:
        return f'dag(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class hg:
    def __init__(self):
        self.name: str = 'HectoGram'
        self.unit: str = 'hg'
    
    def __repr__(self) -> str:
        return f'hg(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class kg:
    def __init__(self):
        self.name: str = 'KiloGram'
        self.unit: str = 'kg'
    
    def __repr__(self) -> str:
        return f'kg(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

# Volume
class ml:
    def __init__(self):
        self.name: str = 'MilliLiter'
        self.unit: str = 'ml'
    
    def __repr__(self) -> str:
        return f'ml(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class cl:
    def __init__(self):
        self.name: str = 'CentiLiter'
        self.unit: str = 'cl'
    
    def __repr__(self) -> str:
        return f'cl(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class dl:
    def __init__(self):
        self.name: str = 'DeciLiter'
        self.unit: str = 'dl'
    
    def __repr__(self) -> str:
        return f'dl(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class l:
    def __init__(self):
        self.name: str = 'Liter'
        self.unit: str = 'l'
    
    def __repr__(self) -> str:
        return f'l(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class dal:
    def __init__(self):
        self.name: str = 'DekaLiter'
        self.unit: str = 'da'
    
    def __repr__(self) -> str:
        return f'da(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class hl:
    def __init__(self):
        self.name: str = 'HectoLiter'
        self.unit: str = 'hl'
    
    def __repr__(self) -> str:
        return f'hl(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class kl:
    def __init__(self):
        self.name: str = 'KiloLiter'
        self.unit: str = 'kl'
    
    def __repr__(self) -> str:
        return f'kl(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

# Length
class mm:
    def __init__(self):
        self.name: str = 'MilliMeter'
        self.unit: str = 'mm'
    
    def __repr__(self) -> str:
        return f'mm(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class cm:
    def __init__(self):
        self.name: str = 'CentiMeter'
        self.unit: str = 'cm'
    
    def __repr__(self) -> str:
        return f'cm(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class dm:
    def __init__(self):
        self.name: str = 'DeciMeter'
        self.unit: str = 'dm'
    
    def __repr__(self) -> str:
        return f'dm(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class m:
    def __init__(self):
        self.name: str = 'Meter'
        self.unit: str = 'm'
    
    def __repr__(self) -> str:
        return f'm(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class dam:
    def __init__(self):
        self.name: str = 'DekaMeter'
        self.unit: str = 'dam'
    
    def __repr__(self) -> str:
        return f'dam(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class hm:
    def __init__(self):
        self.name: str = 'HectoMeter'
        self.unit: str = 'hm'
    
    def __repr__(self) -> str:
        return f'hm(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}' 

class km:
    def __init__(self):
        self.name: str = 'KiloMeter'
        self.unit: str = 'km'
    
    def __repr__(self) -> str:
        return f'km(name={self.name}, unit={self.unit})'

    def __str__(self) -> str:
        return f'{self.unit}'
